/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitArgus.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2007 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds an argus distribution.  See
//   ARGUS Collaboration, H. Albrecht et al., Phys. Lett. 254, 288 (1991).
//
// Has an option to model a slope in xi as a function of an MVA given by 
// *mgr.nnOutPrime()
//

#include "AFit/AFitArgus.hh"

#ifdef __BABARROOFIT__
#include "RooFitModels/RooArgusBG.hh"
#include "RooFitCore/RooFormulaVar.hh"
#include "RooFitCore/RooNumIntConfig.hh"
#else
#include "RooArgusBG.h"
#include "RooFormulaVar.h"
#include "RooNumIntConfig.h"
#endif

ClassImp(AFitArgus)
  ;

AFitArgus::AFitArgus(RooAbsReal& x, TString name, RooArgSet* discVars)
  : endpt(name + "endpt","Half of Y(4S) Mass",5.290,"GeV/c2"),
    xi(name + "xi","Background Shape Parameter",-50.,-200.,0.),
    power(name+"power", "power of the Argus function", 0.5),
    modelNNcorr(name +"modelNNcorr", "model correlation with NN ?"),
    MNNoffset(name+"MNNoffset","MES-NN corr offset",0,-100,100), 
    MNNslope(name+"MNNslope","MES-NN corr slope",0,-100,100)
 {
  // Constructor
   _name     = name;
  _discVars  = discVars;

  _x = &x;

  //modelNNcorr.defineType("no");
  //modelNNcorr.defineType("yes");
  //modelNNcorr.setLabel("no");

  varSet.add(endpt);
  varSet.add(xi);
  varSet.add(power);
  //  varSet.add(modelNNcorr);
  //varSet.add(MNNoffset);
  //varSet.add(MNNslope);
  varSet.Print();

  readDataCard();
}

void AFitArgus::buildPdf() {
  // Build the Pdf
  RooAbsReal* shapepar=&xi;

  /*
  if (modelNNcorr=="yes") {
    if(_discVars) {
      AFitDiscVarManager mgr(_discVars);
      RooFormulaVar* nirvana=new RooFormulaVar(_name+"Xi_prime","@0+@1*@2",RooArgList(MNNoffset,MNNslope,*mgr.nnOutPrime()));
      shapepar=nirvana;
    } else {
      cout << ClassName() << " : Configuration ERROR - _discVars is a null pointer and modelNNcorr = yes" << endl;
      assert(0);
    }
  }
  */

  // For the Argus function we need to ask for better numerical integration in RooFitCore
  RooNumIntConfig ourConfig;
  ourConfig.setEpsAbs(1e-200);
  ourConfig.setEpsRel(1e-10);
  _thePdf = new RooArgusBG(_name, "Argus Function", *_x, endpt, *shapepar, power);

  _thePdf->setIntegratorConfig(ourConfig);
}

