/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitBukin.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single Bukin distribution.

#include "AFit/AFitBukin.hh"
#ifdef __BABARROOFIT__
// RooFit includes
#include "RooFitModels/RooBukinPdf.hh"
#else
// RooFit includes
#include "RooBukinPdf.h"
#endif

#include "TIterator.h"

ClassImp(AFitBukin)
  ;

AFitBukin::AFitBukin(RooAbsReal& x, TString name)
  :  Xp(name+"Xp","Xp", 0.5, 0.0, 1.0),
     sigp(name+"sigp","sigp", 0.1, 0.0, 1.0),
     xi(name+"xi","xi", -0.2, 0.0, 1.0),
     rho1(name+"rho1","rho1", 0.1, 0.0, 1.0),
     rho2(name+"rho2","rho2", 0.2, 0.0, 1.0)
 {
  // Constructor
  _name     = name;

  _x = &x;

  varSet.addOwned(Xp);
  varSet.addOwned(sigp);
  varSet.addOwned(xi);
  varSet.addOwned(rho1);
  varSet.addOwned(rho2);

  readDataCard();
}

void AFitBukin::buildPdf() {
  _thePdf = new RooBukinPdf(_name, "Bukin PDF", *_x, Xp, sigp, xi, rho1, rho2);
}

