/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitCheby.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2007 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
//
//  AFitCheby(RooRealVar& x, TString name, TString types) :
//

#include "AFit/AFitCheby.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooChebychev.hh"
#else
#include "RooChebychev.h"
#endif

#include "TString.h"

ClassImp(AFitCheby)
  ;

AFitCheby::AFitCheby(RooAbsReal& x, TString name, Int_t n) 
{
  // Constructor
  _order = n;
  _name  = name;
  _x     = &x;

  readDataCard();
}

AFitCheby::~AFitCheby() {
  cout << ClassName() << ":destructor to implement DELETE THE INSTANTIATED FRACS AND PDFS!" << endl;
}

void AFitCheby::buildPdf() {
  // Build the Pdf
  for(int i = 0; i < _order; i++) {
    TString thisName = _name; thisName += "_p"; thisName += (long)i; thisName.ReplaceAll(" ", "");
    TString thisTitle = "Cheby PDF Coefficent: "; thisTitle += (long)i; thisTitle.ReplaceAll(" ", "");
    coefList.add(* new RooRealVar (thisName, thisTitle, 0.0, -1.0, 1.0) );
  }

  varSet.add(coefList);
  readDataCard();

  _thePdf = new RooChebychev(_name, "Chebychev polynomial PDF", *_x, coefList);
}

