/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitDecay.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2009 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a PDF for B decays 
// produced at the Y(4S) resonance decaying.

#include "AFit/AFitDecay.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooDecay.hh"
#else
#include "RooDecay.h"
#endif

#include "TIterator.h"

ClassImp(AFitDecay)
  ;

AFitDecay::AFitDecay(RooAbsReal& x, TString name)
  : 
  _tau(name+"_tau", "lifetime", 1.54, 1.0, 2.0) ,
  _type(name + "_type", "basis type", "DoubleSided"),
  _resolutionModelName(name+"_resolution_model", "Resolution Model", "Resolution")
 {
  // Constructor
  _name     = name;

  _t = (RooRealVar*)&x;

  varSet.addOwned(_tau);
  varSet.addOwned(_type);
  varSet.addOwned(_resolutionModelName);

  readDataCard();
}

AFitDecay::~AFitDecay() {
}

void AFitDecay::buildPdf() {
  // Build the Pdf

  _theResolutionModel = dynamic_cast<RooResolutionModel*>(globalConfig.find(_resolutionModelName.getVal()));
  if(!_theResolutionModel) {
    cout << "  Resolution Model " << _resolutionModelName.getVal() << " does not exist" << endl;
    return;
  } else {
    cout << "  Resolution Model " << _resolutionModelName.getVal() << " has been found and will be used (address = " << _theResolutionModel << ")" <<endl;
  }

  TString thisType = _type.getVal();

  if(!thisType.CompareTo("DoubleSided", TString::kExact) ) {
    cout << "making pdf with double sided basis" << endl;
    _thePdf = new RooDecay(_name,"Decay PDF: double sided",*_t, _tau, *_theResolutionModel, RooDecay::DoubleSided);
  }
  else if(!thisType.CompareTo("SingleSided", TString::kExact) ) {
    cout << "making pdf with single sided basis" << endl;
    _thePdf = new RooDecay(_name,"Decay PDF: single sided",*_t, _tau, *_theResolutionModel, RooDecay::SingleSided);
  }
  else if(!thisType.CompareTo("Flipped", TString::kExact) ) {
    cout << "making pdf with flipped basis" << endl;
    _thePdf = new RooDecay(_name,"Decay PDF: flipped",*_t, _tau, *_theResolutionModel, RooDecay::Flipped);
  } else {
    cout << "unknown basis for " << ClassName() << " _type = " << _type.getVal() << " " << _thePdf << endl;
    _thePdf = 0;
  }

}

