/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitKeys.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2009 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single histogram PDF distribution

#include "AFit/AFitKeys.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooKeysPdf.hh"
#else
#include "RooKeysPdf.h"
#endif

ClassImp(AFitKeys)
  ;

AFitKeys::AFitKeys(RooAbsReal& x, TString name)
  : datafile(name+"_file", "File name", "null"),
    treename(name+"_tree", "Histogram name", "null"),
    mirror(name+"_mirror", "Mirror Option for KEYS PDF"),
    rho(name+"_rho", "smoothing parameter", 0)
 {
  // Constructor
  _name     = name;

  _x = &x;

  mirror.defineType("NoMirror");
  mirror.defineType("MirrorLeft");
  mirror.defineType("MirrorRight");
  mirror.defineType("MirrorBoth");
  mirror.defineType("MirrorAsymLeft");
  mirror.defineType("MirrorAsymLeftRight");
  mirror.defineType("MirrorAsymRight");
  mirror.defineType("MirrorLeftAsymRight");
  mirror.defineType("MirrorAsymBoth");
  mirror.setLabel("NoMirror");

  varSet.add(datafile);
  varSet.add(treename);
  varSet.add(mirror);
  varSet.add(rho);

  readDataCard();
}

AFitKeys::~AFitKeys() {
  delete dataset;
}

void AFitKeys::buildPdf() {
  // Build the Pdf
  TFile f( datafile.getVal() );
  tree = (TTree*)f.Get(treename.getVal());
  if(!tree) {
    cout << ClassName() << "::ERROR - unable to get tree " << treename.getVal() << " from file " << datafile.getVal() << "." << endl;
    assert(0);
  }

  dataset = new RooDataSet(_name + "_dataset", "Data set",  tree, RooArgList(*_x) );
  if(mirror == "NoMirror")                 _thePdf = new RooKeysPdf(_name, "Histogram PDF", *_x, *dataset, RooKeysPdf::NoMirror, (Int_t)rho.getVal());
  else if(mirror == "MirrorLeft")          _thePdf = new RooKeysPdf(_name, "Histogram PDF", *_x, *dataset, RooKeysPdf::MirrorLeft, (Int_t)rho.getVal());
  else if(mirror == "MirrorRight")         _thePdf = new RooKeysPdf(_name, "Histogram PDF", *_x, *dataset, RooKeysPdf::MirrorRight, (Int_t)rho.getVal());
  else if(mirror == "MirrorBoth")          _thePdf = new RooKeysPdf(_name, "Histogram PDF", *_x, *dataset, RooKeysPdf::MirrorBoth, (Int_t)rho.getVal());
  else if(mirror == "MirrorAsymLeft")      _thePdf = new RooKeysPdf(_name, "Histogram PDF", *_x, *dataset, RooKeysPdf::MirrorAsymLeft, (Int_t)rho.getVal());
  else if(mirror == "MirrorAsymLeftRight") _thePdf = new RooKeysPdf(_name, "Histogram PDF", *_x, *dataset, RooKeysPdf::MirrorAsymLeftRight, (Int_t)rho.getVal());
  else if(mirror == "MirrorAsymRight")     _thePdf = new RooKeysPdf(_name, "Histogram PDF", *_x, *dataset, RooKeysPdf::MirrorAsymRight, (Int_t)rho.getVal());
  else if(mirror == "MirrorLeftAsymRight") _thePdf = new RooKeysPdf(_name, "Histogram PDF", *_x, *dataset, RooKeysPdf::MirrorLeftAsymRight, (Int_t)rho.getVal());
  else if(mirror == "MirrorAsymBoth")      _thePdf = new RooKeysPdf(_name, "Histogram PDF", *_x, *dataset, RooKeysPdf::MirrorAsymBoth, (Int_t)rho.getVal());
}

