/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitNovosibirskShape.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2007 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single CBShape distribution (Crystal Ball).

#include "AFit/AFitNovosibirskShape.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooNovosibirsk.hh"
#else
#include "RooNovosibirsk.h"
#endif

ClassImp(AFitNovosibirskShape)
  ;

AFitNovosibirskShape::AFitNovosibirskShape(RooAbsReal& x, TString name)
  : peak(name+"peak", "Peak of CBShape", 0.0, -10.0, 10.0)
    , width(name+"width", "Width of CBShape", 1.0, 0.0, 10.0)
    , tail(name+"tail", "Width of asymmetric Gaussian (Left)", 1.0, 0.0, 10.0)
 {
  // Constructor
  _name     = name;

  _x = &x;
  const RooArgSet * argVarSet = _x->getVariables();
  if(argVarSet->getSize() == 1) {
    TIterator * iter = argVarSet->createIterator();
    RooRealVar * var = (RooRealVar*)iter->Next();
    if(var){
      peak.setRange(var->getMin(), var->getMax());
      width.setRange(0.0,  var->getMax()-var->getMin());
    }
  }

  varSet.add(peak);
  varSet.add(width);
  varSet.add(tail);

  readDataCard();
}

void AFitNovosibirskShape::buildPdf() {
  // Build the Pdf
    _thePdf = new RooNovosibirsk(_name, "Novosibirsk Shape PDF", *_x, peak, width, tail);
}

