/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitSigmoidPdf.cc
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [PDF] --
// Implementation of a RooAbsPdf Sigmoid function of the form
//           pdf = 1/(1 + e^a[x+b])
//
#include <math.h>

#include "AFit/AFitSigmoidPdf.hh"
#ifdef __BABARROOFIT__
#include "RooFitCore/RooAbsReal.hh"
#include "RooFitCore/RooRealVar.hh"
#else
#include "RooAbsReal.h"
#include "RooRealVar.h"
#endif

ClassImp(AFitSigmoidPdf)

AFitSigmoidPdf::AFitSigmoidPdf(const char *name, const char *title,
		       RooAbsReal& _x, RooAbsReal& _a, 
		       RooAbsReal& _b) :
  RooAbsPdf(name, title),
  x("x", "Dependent", this, _x),
  a("a", "exponent scale factor", this, _a),
  b("b", "exponent offset", this, _b)
{
}

AFitSigmoidPdf::AFitSigmoidPdf(const AFitSigmoidPdf& other, const char* name) :
  RooAbsPdf(other, name), x("x", this, other.x), a("a", this, other.a),
  b("b", this, other.b)
{
}

Double_t AFitSigmoidPdf::evaluate() const {
  double exponent = a*(x+b);
  double denominator = 1 + exp(exponent);
  if(denominator == 0) return 0;
  else return 1/denominator;
}

